-- ============================================================================
-- == HTConfig - Provides functions for creating, reading, updating and      ==
-- ==            deleting the configuration data used to configure the       ==
-- ==            HalonaTools addon.                                          ==
-- ============================================================================

HTConfig       = LibStub("AceAddon-3.0"):NewAddon("HTConfig", "AceConsole-3.0", "AceEvent-3.0")
local L        = LibStub("AceLocale-3.0"):GetLocale("HalonaTools")

local db       = {} -- Reference variable used to persist data between sessions.
local defaults = {} -- Reference variable used to persist data between sessions.
local options  = {}                -- Used to provide Ace3/Blizzard GUI options.

-- ============================================================================
-- == OnInitialize()                                                         ==
-- ==                                                                        ==
-- == This function is called when the addon is initialised.                 ==
-- ============================================================================

function HTConfig:OnInitialize()

  HTConfig:BuildDBTable()
  HTConfig:BuildOptionsTable()
  HTConfig:RegisterOptionsTable()
  HTConfig:SetDefaultPropertyValues()

end

-- ============================================================================
-- == OnEnable()                                                             ==
-- ==                                                                        ==
-- == This function is called when the addon is enabled.                     ==
-- ============================================================================

function HTConfig:OnEnable()
end

-- ============================================================================
-- == OnEnable()                                                             ==
-- ==                                                                        ==
-- == This function is called when the addon is disabled.                    ==
-- ============================================================================

function HTConfig:OnDisable()
end

-- ============================================================================
-- == BuildDBTable()                                                         ==
-- ==                                                                        ==
-- == This function builds the default db table. This table is persisted     ==
-- == between sessions by the AceDB library.                                 ==
-- ============================================================================

function HTConfig:BuildDBTable()

  defaults = {
    profile =  {
      -- General status flags and data values.
      addonName                                = L["addon-name"],
      isEnabledAutoInvitations                 = true,
      isEnabledAutoRaidPromotions              = true,
      isEnabledAutoRIAResponse                 = true,
      isEnabledAutoRQAResponse                 = true,
      isEnabledAlertNewAddonVersion            = true,
      isEnabledDebugMode                       = true,
      chatWindowTextMaxWidth                   = 45,
      maxAddonVersionSeen                      = L["addon-version-number"],

      -- BuffMonitor - Cataclysm Data Items.
      isEnabledBuffMonitorCataFlasks           = true,
      isEnabledBuffMonitorCataBattleElixirs    = true,
      isEnabledBuffMonitorCataGuardianElixirs  = true,
      isEnabledBuffMonitorCataFood             = true,
      isEnabledBuffMonitorCataPoisons          = true,

      -- BuffMonitor - Wrath Data Items.
      isEnabledBuffMonitorWrathFlasks          = true,
      isEnabledBuffMonitorWrathBattleElixirs   = true,
      isEnabledBuffMonitorWrathGuardianElixirs = true,
      isEnabledBuffMonitorWrathFood            = true,
      isEnabledBuffMonitorWrathPoisons         = true,

      -- BuffMonitor - Reporting Options.
      isEnabledBuffMonitorExpiryTimeCheck      = true,
      buffMonitorExpiryTimeLimit               = 5,

      isEnabledBuffMonitorCheckFlasks          = true,
      isEnabledBuffMonitorCheckBattleElixirs   = true,
      isEnabledBuffMonitorCheckGuardianElixirs = true,
      isEnabledBuffMonitorCheckFood            = true,
      isEnabledBuffMonitorCheckPoisons         = false,

      -- Recruitment Message Sender.
      isEnabledRecruitmentMessageSender        = true,
      isEnabledRMSGuildLocked                  = true,
      preferredRMSGuild                        = L["cfg-default-guild-name"],
      recruitmentMessage                       = L["ldb-menu-item-setngrmessage-msg"],
      recruitmentInterval                      = 900,

      -- BusyResponder.
      isEnabledBusyResponder                   = false,
      isGuildMemberAllowed                     = true,
      isGuildOfficerAllowed                    = true,
      isRaidMemberAllowed                      = true,
      isPartyMemberAllowed                     = true,
      isFriendAllowed                          = true,
      isRealIDFriendAllowed                    = true,
      brMessageOutgoing                        = L["con-busy-responder-out-msg-busy-01"]
    },
  }

  self.db = LibStub("AceDB-3.0"):New("HalonaToolsDB", defaults, "Default")

end

-- ============================================================================
-- == BuildOptionsTable()                                                    ==
-- ==                                                                        ==
-- == This function builds the default options table. This table is          ==
-- == used to generate both the command-line options and the configuration   ==
-- == options available through the Blizzard Addons UI by the AceConfig lib. ==
-- ============================================================================

function HTConfig:BuildOptionsTable()

  options = {
    name = L["addon-name"],
    handler = HTConfig,
    type = 'group',
    args = {
      isEnabledAutoInvitations = {
        type = "toggle",
        name = L["cfg-feature-name-autoinvitations"],
        desc = L["cfg-feature-desc-autoinvitations"],
        get = "GetIsEnabledAutoInvitations",
        set = "SetIsEnabledAutoInvitations",
      },
      isEnabledDebugMode = {
        type = "toggle",
        name = L["cfg-feature-name-debugmode"],
        desc = L["cfg-feature-desc-debugmode"],
        get = "GetIsEnabledDebugMode",
        set = "SetIsEnabledDebugMode",
      },
    },
  }

end

-- ============================================================================
-- == RegisterOptionsTable()                                                 ==
-- ==                                                                        ==
-- == This function registers the default options table.                     ==
-- ============================================================================

function HTConfig:RegisterOptionsTable()

    LibStub("AceConfig-3.0"):RegisterOptionsTable("HalonaTools", options)
    self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions(L["addon-name"], L["addon-name"])
    self:RegisterChatCommand(L["cfg-console-command-long"],  "ChatCommand")
    self:RegisterChatCommand(L["cfg-console-command-short"], "ChatCommand")

end

-- ============================================================================
-- == SetDefaultPropertyValues()                                             ==
-- ==                                                                        ==
-- == This function sets internal properties to default values.              ==
-- ============================================================================

function HTConfig:SetDefaultPropertyValues()

    -- HTConfig.message = "Welcome Home!"

end

-- ============================================================================
-- == ChatCommand(input)                                                     ==
-- ==                                                                        ==
-- == This function responds to calls to the addon via chat commands.        ==
-- ============================================================================

function HTConfig:ChatCommand(input)

  if not input or input:trim() == "" then
    InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
  else
    LibStub("AceConfigCmd-3.0").HandleCommand(HalonaTools, L["cfg-console-command-short"], L["addon-name"], input)
  end

end

-- ============================================================================
-- == IsFeatureEnabled(feature)                                              ==
-- ==                                                                        ==
-- == This function checks whether the indicated feature is enabled,         ==
-- == returning 'true' if the feature is enabled or 'false' otherwise.       ==
-- ============================================================================

function HTConfig:IsFeatureEnabled(feature)

  if feature == L["cfg-feature-name-autoinvitations"] then
    return HTConfig:GetIsEnabledAutoInvitations(nil)
  end

  if feature == L["cfg-feature-name-autoraidpromotions"] then
    return HTConfig:GetIsEnabledAutoRaidPromotions(nil)
  end

  if feature == L["cfg-feature-name-debugmode"] then
    return HTConfig:GetIsEnabledDebugMode(nil)
  end

  return false

end

-- ============================================================================
-- == ToggleValue(value)                                                     ==
-- ==                                                                        ==
-- == Toggles the supplied value.                                            ==
-- ============================================================================

function HTConfig:ToggleValue(value)

    if value == true then
      return false
    else
      return true
    end

end

-- ============================================================================
-- == ACCESSORS/MUTATORS* only beyond this point.                            ==
-- ==                                                                        ==
-- == The remainder of this file contains the accessors and mutators for the ==
-- == various different variables/data-items managed as part of the HTConfig ==
-- == model.                                                                 ==
-- ==                                                                        ==
-- == * Also known less formally as 'getters and setters'.                   ==
-- ============================================================================

-- ============================================================================
-- == GetMessage(info)                                                       ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetMessage(info)
    return self.db.profile.message
end

-- ============================================================================
-- == SetMessage(info, newValue)                                             ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetMessage(info, newValue)
    self.db.profile.message = newValue
end

-- ============================================================================
-- == GetIsEnabledAutoInvitations(info)                                      ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledAutoInvitations(info)
    return self.db.profile.isEnabledAutoInvitations
end

-- ============================================================================
-- == SetIsEnabledAutoInvitations(info, newValue)                            ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledAutoInvitations(info, newValue)
    self.db.profile.isEnabledAutoInvitations = newValue
end

-- ============================================================================
-- == ToggleIsEnabledAutoInvitations()                                       ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledAutoInvitations()
    self.db.profile.isEnabledAutoInvitations = HTConfig:ToggleValue(HTConfig:GetIsEnabledAutoInvitations(nil))
end

-- ============================================================================
-- == GetIsEnabledAutoRaidPromotions(info)                                   ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledAutoRaidPromotions(info)
    return self.db.profile.isEnabledAutoRaidPromotions
end

-- ============================================================================
-- == SetIsEnabledAutoRaidPromotions(info, newValue)                         ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledAutoRaidPromotions(info, newValue)
    self.db.profile.isEnabledAutoRaidPromotions = newValue
end

-- ============================================================================
-- == ToggleIsEnabledAutoRaidPromotions()                                    ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledAutoRaidPromotions()
    self.db.profile.isEnabledAutoRaidPromotions = HTConfig:ToggleValue(HTConfig:GetIsEnabledAutoRaidPromotions(nil))
end

-- ============================================================================
-- == GetIsEnabledAutoRIAResponse(info)                                      ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledAutoRIAResponse(info)
    return self.db.profile.isEnabledAutoRIAResponse
end

-- ============================================================================
-- == SetIsEnabledAutoRaidPromotions(info, newValue)                         ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledAutoRIAResponse(info, newValue)
    self.db.profile.isEnabledAutoRIAResponse = newValue
end

-- ============================================================================
-- == ToggleIsEnabledAutoRIAResponse()                                       ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledAutoRIAResponse()
    self.db.profile.isEnabledAutoRIAResponse = HTConfig:ToggleValue(HTConfig:GetIsEnabledAutoRIAResponse(nil))
end

-- ============================================================================
-- == GetIsEnabledAutoRQAResponse(info)                                     ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledAutoRQAResponse(info)
    return self.db.profile.isEnabledAutoRQAResponse
end

-- ============================================================================
-- == SetIsEnabledAutoRQAResponse(info, newValue)                            ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledAutoRQAResponse(info, newValue)
    self.db.profile.isEnabledAutoRQAResponse = newValue
end

-- ============================================================================
-- == ToggleIsEnabledAutoRQAResponse()                                       ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledAutoRQAResponse()
    self.db.profile.isEnabledAutoRQAResponse = HTConfig:ToggleValue(HTConfig:GetIsEnabledAutoRQAResponse(nil))
end

-- ============================================================================
-- == GetIsEnabledDebugMode(info)                                            ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledDebugMode(info)
    return self.db.profile.isEnabledDebugMode
end

-- ============================================================================
-- == SetIsEnabledDebugMode(info, newValue)                                  ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledDebugMode(info, newValue)
    self.db.profile.isEnabledDebugMode = newValue
end

-- ============================================================================
-- == ToggleIsEnabledDebugMode()                                             ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledDebugMode()
    self.db.profile.isEnabledDebugMode = HTConfig:ToggleValue(HTConfig:GetIsEnabledDebugMode(nil))
end

-- ============================================================================
-- == GetIsEnabledAlertNewAddonVersion(info)                                 ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledAlertNewAddonVersion(info)
    return self.db.profile.isEnabledAlertNewAddonVersion
end

-- ============================================================================
-- == SetIsEnabledAlertNewAddonVersion(info, newValue)                       ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledAlertNewAddonVersion(info, newValue)
    self.db.profile.isEnabledAlertNewAddonVersion = newValue
end

-- ============================================================================
-- == ToggleIsEnabledAlertNewAddonVersion()                                  ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledAlertNewAddonVersion()
    self.db.profile.isEnabledAlertNewAddonVersion = HTConfig:ToggleValue(HTConfig:GetIsEnabledAlertNewAddonVersion(nil))
end

-- ============================================================================
-- == GetChatWindowTextMaxWidth(info)                                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetChatWindowTextMaxWidth(info)
    return self.db.profile.chatWindowTextMaxWidth
end

-- ============================================================================
-- == SetChatWindowTextMaxWidth(info, newValue)                              ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetChatWindowTextMaxWidth(info, newValue)
    self.db.profile.chatWindowTextMaxWidth = newValue
end

-- ============================================================================
-- == GetMaxAddonVersionSeen(info)                                            ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetMaxAddonVersionSeen(info)
    return self.db.profile.maxAddonVersionSeen
end

-- ============================================================================
-- == SetMaxAddonVersionSeen(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetMaxAddonVersionSeen(info, newValue)
    self.db.profile.maxAddonVersionSeen = newValue
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCataFlasks(info)                                ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCataFlasks(info)
    return self.db.profile.isEnabledBuffMonitorCataFlasks
end

-- ============================================================================
-- == SetIsEnabledBuffMonitorCataFlasks(info, newValue)                      ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCataFlasks(info, newValue)
    self.db.profile.isEnabledBuffMonitorCataFlasks = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCataFlasks()                                 ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCataFlasks()
    self.db.profile.isEnabledBuffMonitorCataFlasks = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCataFlasks(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCataBattleElixirs(info)                         ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCataBattleElixirs(info)
    return self.db.profile.isEnabledBuffMonitorCataBattleElixirs
end

-- ============================================================================
-- == BuffMonitorCataBattleElixirs(info, newValue)                           ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCataBattleElixirs(info, newValue)
    self.db.profile.isEnabledBuffMonitorCataBattleElixirs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCataBattleElixirs()                          ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCataBattleElixirs()
    self.db.profile.isEnabledBuffMonitorCataBattleElixirs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCataBattleElixirs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCataGuardianElixirs(info)                       ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCataGuardianElixirs(info)
    return self.db.profile.isEnabledBuffMonitorCataGuardianElixirs
end

-- ============================================================================
-- == BuffMonitorCataGuardianElixirs(info, newValue)                         ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCataGuardianElixirs(info, newValue)
    self.db.profile.isEnabledBuffMonitorCataGuardianElixirs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCataGuardianElixirs()                        ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCataGuardianElixirs()
    self.db.profile.isEnabledBuffMonitorCataGuardianElixirs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCataGuardianElixirs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCataFood(info)                                  ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCataFood(info)
    return self.db.profile.isEnabledBuffMonitorCataFood
end

-- ============================================================================
-- == BuffMonitorCataFood(info, newValue)                                    ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCataFood(info, newValue)
    self.db.profile.isEnabledBuffMonitorCataFood = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCataFood()                                   ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCataFood()
    self.db.profile.isEnabledBuffMonitorCataFood = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCataFood(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCataPoisons(info)                               ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCataPoisons(info)
    return self.db.profile.isEnabledBuffMonitorCataPoisons
end

-- ============================================================================
-- == BuffMonitorCataPoisons(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCataPoisons(info, newValue)
    self.db.profile.isEnabledBuffMonitorCataPoisons = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCataPoisons()                                ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCataPoisons()
    self.db.profile.isEnabledBuffMonitorCataPoisons = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCataPoisons(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorWrathFlasks(info)                               ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorWrathFlasks(info)
    return self.db.profile.isEnabledBuffMonitorWrathFlasks
end

-- ============================================================================
-- == BuffMonitorWrathFlasks(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorWrathFlasks(info, newValue)
    self.db.profile.isEnabledBuffMonitorWrathFlasks = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorWrathFlasks()                                ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorWrathFlasks()
    self.db.profile.isEnabledBuffMonitorWrathFlasks = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorWrathFlasks(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorWrathBattleElixirs(info)                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorWrathBattleElixirs(info)
    return self.db.profile.isEnabledBuffMonitorWrathBattleElixirs
end

-- ============================================================================
-- == BuffMonitorWrathBattleElixirs(info, newValue)                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorWrathBattleElixirs(info, newValue)
    self.db.profile.isEnabledBuffMonitorWrathBattleElixirs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorWrathBattleElixirs()                         ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorWrathBattleElixirs()
    self.db.profile.isEnabledBuffMonitorWrathBattleElixirs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorWrathBattleElixirs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorWrathGuardianElixirs(info)                      ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorWrathGuardianElixirs(info)
    return self.db.profile.isEnabledBuffMonitorWrathGuardianElixirs
end

-- ============================================================================
-- == BuffMonitorWrathGuardianElixirs(info, newValue)                        ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorWrathGuardianElixirs(info, newValue)
    self.db.profile.isEnabledBuffMonitorWrathGuardianElixirs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorWrathGuardianElixirs()                       ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorWrathGuardianElixirs()
    self.db.profile.isEnabledBuffMonitorWrathGuardianElixirs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorWrathGuardianElixirs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorWrathFood(info)                                 ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorWrathFood(info)
    return self.db.profile.isEnabledBuffMonitorWrathFood
end

-- ============================================================================
-- == BuffMonitorWrathFood(info, newValue)                                   ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorWrathFood(info, newValue)
    self.db.profile.isEnabledBuffMonitorWrathFood = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorWrathFood()                                  ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorWrathFood()
    self.db.profile.isEnabledBuffMonitorWrathFood = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorWrathFood(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorWrathPoisons(info)                              ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorWrathPoisons(info)
    return self.db.profile.isEnabledBuffMonitorWrathPoisons
end

-- ============================================================================
-- == BuffMonitorWrathPoisons(info, newValue)                                ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorWrathPoisons(info, newValue)
    self.db.profile.isEnabledBuffMonitorWrathPoisons = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorWrathPoisons()                               ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorWrathPoisons()
    self.db.profile.isEnabledBuffMonitorWrathPoisons = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorWrathPoisons(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorExpiryTimeCheck(info)                           ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorExpiryTimeCheck(info)
    return self.db.profile.isEnabledBuffMonitorExpiryTimeCheck
end

-- ============================================================================
-- == BuffMonitorExpiryTimeCheck(info, newValue)                             ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorExpiryTimeCheck(info, newValue)
    self.db.profile.isEnabledBuffMonitorExpiryTimeCheck = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorExpiryTimeCheck()                            ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorExpiryTimeCheck()
    self.db.profile.isEnabledBuffMonitorExpiryTimeCheck = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorExpiryTimeCheck(nil))
end

-- ============================================================================
-- == GetBuffMonitorExpiryTimeLimit(info)                                    ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetBuffMonitorExpiryTimeLimit(info)
    return self.db.profile.buffMonitorExpiryTimeLimit
end

-- ============================================================================
-- == SetBuffMonitorExpiryTimeLimit(info, newValue)                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetBuffMonitorExpiryTimeLimit(info, newValue)
    self.db.profile.buffMonitorExpiryTimeLimit = newValue
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCheckFlasks(info)                               ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCheckFlasks(info)
    return self.db.profile.isEnabledBuffMonitorCheckFlasks
end

-- ============================================================================
-- == BuffMonitorCheckFlasks(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCheckFlasks(info, newValue)
    self.db.profile.isEnabledBuffMonitorCheckFlasks = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCheckFlasks()                                ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCheckFlasks()
    self.db.profile.isEnabledBuffMonitorCheckFlasks = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCheckFlasks(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCheckBattleElixirs(info)                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCheckBattleElixirs(info)
    return self.db.profile.isEnabledBuffMonitorCheckBattleElixirs
end

-- ============================================================================
-- == BuffMonitorCheckBattleElixirs(info, newValue)                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCheckBattleElixirs(info, newValue)
    self.db.profile.isEnabledBuffMonitorCheckBattleElixirs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCheckBattleElixirs()                         ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCheckBattleElixirs()
    self.db.profile.isEnabledBuffMonitorCheckBattleElixirs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCheckBattleElixirs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCheckGuardianElixirs(info)                      ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCheckGuardianElixirs(info)
    return self.db.profile.isEnabledBuffMonitorCheckGuardianElixirs
end

-- ============================================================================
-- == BuffMonitorCheckGuardianElixirs(info, newValue)                        ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCheckGuardianElixirs(info, newValue)
    self.db.profile.isEnabledBuffMonitorCheckGuardianElixirs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCheckGuardianElixirs()                       ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCheckGuardianElixirs()
    self.db.profile.isEnabledBuffMonitorCheckGuardianElixirs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCheckGuardianElixirs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCheckFood(info)                                 ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCheckFood(info)
    return self.db.profile.isEnabledBuffMonitorCheckFood
end

-- ============================================================================
-- == BuffMonitorCheckFood(info, newValue)                                   ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCheckFood(info, newValue)
    self.db.profile.isEnabledBuffMonitorCheckFood = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCheckFood()                                  ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCheckFood()
    self.db.profile.isEnabledBuffMonitorCheckFood = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCheckFood(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCheckPoisons(info)                              ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCheckPoisons(info)
    return self.db.profile.isEnabledBuffMonitorCheckPoisons
end

-- ============================================================================
-- == BuffMonitorCheckPoisons(info, newValue)                                ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCheckPoisons(info, newValue)
    self.db.profile.isEnabledBuffMonitorCheckPoisons = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCheckPoisons()                               ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCheckPoisons()
    self.db.profile.isEnabledBuffMonitorCheckPoisons = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCheckPoisons(nil))
end

-- ============================================================================
-- == GetIsEnabledRecruitmentMessageSender(info)                             ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledRecruitmentMessageSender(info)
    return self.db.profile.isEnabledRecruitmentMessageSender
end

-- ============================================================================
-- == SetIsEnabledRecruitmentMessageSender(info, newValue)                   ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledRecruitmentMessageSender(info, newValue)
    self.db.profile.isEnabledRecruitmentMessageSender = newValue
end

-- ============================================================================
-- == ToggleIsEnabledRecruitmentMessageSender()                              ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledRecruitmentMessageSender()
    self.db.profile.isEnabledRecruitmentMessageSender = HTConfig:ToggleValue(HTConfig:GetIsEnabledRecruitmentMessageSender(nil))
end

-- ============================================================================
-- == GetIsEnabledRMSGuildLocked(info)                                       ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledRMSGuildLocked(info)
    return self.db.profile.isEnabledRMSGuildLocked
end

-- ============================================================================
-- == SetIsEnabledRMSGuildLocked(info, newValue)                             ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledRMSGuildLocked(info, newValue)
    self.db.profile.isEnabledRMSGuildLocked = newValue
end

-- ============================================================================
-- == ToggleIsEnabledRMSGuildLocked()                                        ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledRMSGuildLocked()
    self.db.profile.isEnabledRMSGuildLocked = HTConfig:ToggleValue(HTConfig:GetIsEnabledRMSGuildLocked(nil))
end

-- ============================================================================
-- == GetPreferredRMSGuild(info)                                             ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetPreferredRMSGuild(info)
    return self.db.profile.preferredRMSGuild
end

-- ============================================================================
-- == SetPreferredRMSGuild(info, newValue)                                   ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetPreferredRMSGuild(info, newValue)
    self.db.profile.preferredRMSGuild = newValue
end

-- ============================================================================
-- == GetRecruitmentMessage(info)                                            ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetRecruitmentMessage(info)
    return self.db.profile.recruitmentMessage
end

-- ============================================================================
-- == SetRecruitmentMessage(info, newValue)                                  ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetRecruitmentMessage(info, newValue)
    self.db.profile.recruitmentMessage = newValue
end

-- ============================================================================
-- == GetRecruitmentInterval(info)                                           ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetRecruitmentInterval(info)
    return self.db.profile.recruitmentInterval
end

-- ============================================================================
-- == SetRecruitmentInterval(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetRecruitmentInterval(info, newValue)
    self.db.profile.recruitmentInterval = newValue
end

-- ============================================================================
-- == GetIsEnabledBusyResponder(info)                                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBusyResponder(info)
    return self.db.profile.isEnabledBusyResponder
end

-- ============================================================================
-- == SetIsEnabledBusyResponder(info, newValue)                              ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBusyResponder(info, newValue)
    self.db.profile.isEnabledBusyResponder = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBusyResponder()                                         ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBusyResponder()
    self.db.profile.isEnabledBusyResponder = HTConfig:ToggleValue(HTConfig:GetIsEnabledBusyResponder(nil))
end

-- ============================================================================
-- == GetIsGuildMemberAllowed(info)                                          ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsGuildMemberAllowed(info)
    return self.db.profile.isGuildMemberAllowed
end

-- ============================================================================
-- == SetIsGuildMemberAllowed(info, newValue)                                ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsGuildMemberAllowed(info, newValue)
    self.db.profile.isGuildMemberAllowed = newValue
end

-- ============================================================================
-- == ToggleIsGuildMemberAllowed()                                           ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsGuildMemberAllowed()
    self.db.profile.isGuildMemberAllowed = HTConfig:ToggleValue(HTConfig:GetIsGuildMemberAllowed(nil))
end

-- ============================================================================
-- == GetIsGuildOfficerAllowed(info)                                         ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsGuildOfficerAllowed(info)
    return self.db.profile.isGuildOfficerAllowed
end

-- ============================================================================
-- == SetIsGuildOfficerAllowed(info, newValue)                               ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsGuildOfficerAllowed(info, newValue)
    self.db.profile.isGuildOfficerAllowed = newValue
end

-- ============================================================================
-- == ToggleIsGuildOfficerAllowed()                                          ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsGuildOfficerAllowed()
    self.db.profile.isGuildOfficerAllowed = HTConfig:ToggleValue(HTConfig:GetIsGuildOfficerAllowed(nil))
end

-- ============================================================================
-- == GetIsRaidMemberAllowed(info)                                           ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsRaidMemberAllowed(info)
    return self.db.profile.isRaidMemberAllowed
end

-- ============================================================================
-- == SetIsRaidMemberAllowed(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsRaidMemberAllowed(info, newValue)
    self.db.profile.isRaidMemberAllowed = newValue
end

-- ============================================================================
-- == ToggleIsRaidMemberAllowed()                                            ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsRaidMemberAllowed()
    self.db.profile.isRaidMemberAllowed = HTConfig:ToggleValue(HTConfig:GetIsRaidMemberAllowed(nil))
end

-- ============================================================================
-- == GetIsPartyMemberAllowed(info)                                          ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsPartyMemberAllowed(info)
    return self.db.profile.isPartyMemberAllowed
end

-- ============================================================================
-- == SetIsPartyMemberAllowed(info, newValue)                                ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsPartyMemberAllowed(info, newValue)
    self.db.profile.isPartyMemberAllowed = newValue
end

-- ============================================================================
-- == ToggleIsPartyMemberAllowed()                                           ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsPartyMemberAllowed()
    self.db.profile.isPartyMemberAllowed = HTConfig:ToggleValue(HTConfig:GetIsPartyMemberAllowed(nil))
end

-- ============================================================================
-- == GetIsFriendAllowed(info)                                               ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsFriendAllowed(info)
    return self.db.profile.isFriendAllowed
end

-- ============================================================================
-- == SetIsFriendAllowed(info, newValue)                                     ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsFriendAllowed(info, newValue)
    self.db.profile.isFriendAllowed = newValue
end

-- ============================================================================
-- == ToggleIsFriendAllowed()                                                ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsFriendAllowed()
    self.db.profile.isFriendAllowed = HTConfig:ToggleValue(HTConfig:GetIsFriendAllowed(nil))
end

-- ============================================================================
-- == GetIsRealIDFriendAllowed(info)                                         ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsRealIDFriendAllowed(info)
    return self.db.profile.isRealIDFriendAllowed
end

-- ============================================================================
-- == SetIsRealIDFriendAllowed(info, newValue)                               ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsRealIDFriendAllowed(info, newValue)
    self.db.profile.isRealIDFriendAllowed = newValue
end

-- ============================================================================
-- == ToggleIsRealIDFriendAllowed()                                          ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsRealIDFriendAllowed()
    self.db.profile.isRealIDFriendAllowed = HTConfig:ToggleValue(HTConfig:GetIsRealIDFriendAllowed(nil))
end

-- ============================================================================
-- == GetBRMessageOutgoing(info)                                             ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetBRMessageOutgoing(info)
    return self.db.profile.brMessageOutgoing
end

-- ============================================================================
-- == SetBRMessageOutgoing(info, newValue)                                   ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetBRMessageOutgoing(info, newValue)
    self.db.profile.brMessageOutgoing = newValue
end

-- ============================================================================
-- == GetIsEnabledXXX(info)                                                  ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledXXX(info)
    return self.db.profile.isEnabledXXX
end

-- ============================================================================
-- == XXX(info, newValue)                                                    ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledXXX(info, newValue)
    self.db.profile.isEnabledXXX = newValue
end

-- ============================================================================
-- == ToggleIsEnabledXXX()                                                   ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledXXX()
    self.db.profile.isEnabledXXX = HTConfig:ToggleValue(HTConfig:GetIsEnabledXXX(nil))
end
